==> rubrica2-2.0.2.tar.bz2: rubrica2-2.0.2/test/test_contact.c <==
#include <glib.h>
#include <glib-object.h>

#include <libral.h>

void press_key(void)
{
  gchar key;

  g_print("\npress a key");
  scanf("%c", &key);
}


int 
main(int argc, char* argv[])
{
  RContact* contact;
  RContact* copy;
  gchar *first, *middle, *last, *nick, *prof, *pref, *title, *photo;
  gchar *day, *month, *year; 
  

  g_type_init();
  r_lib_init();

  g_print("\nTesting the contact object");
  g_print("\nbuilding a new contact");
  press_key();
  
  contact = r_contact_new();

  g_print("\nFill contact with some values...");
  g_object_set(contact, 
	       "first-name", "given name", 
	       "middle-name", "middle name", 
	       "last-name", "surname", 
	       "nick-name", "TheNick", 
	       "profession", "the profession", 
	       "prefix", "the prefix", 
	       "title", "title", 
	       "photo", "/path/to/contact/photo/photo1.jpg", NULL);
  r_contact_set_birthday(contact, 1, 1, 91);
  g_print(" ok");

  g_print("\nCopying the contact...");
  copy = r_contact_copy(contact);
  g_print(" ok");

  g_print("\nGetting data from copy...");
  g_object_get(copy, 
	       "first-name", &first, 
	       "middle-name", &middle, 
	       "last-name", &last, 
	       "nick-name", &nick,
	       "profession", &prof, 
	       "prefix", &pref,
	       "title", &title, 
	       "photo", &photo, NULL);

  day   = r_contact_get_birth_day(contact);
  month = r_contact_get_birth_month(contact);
  year  = r_contact_get_birth_year(contact);
  g_print(" ok");

  g_print("\n\nWill print copy's values...");
  press_key();

  g_print("\nGiven name: %s\nMiddle name: %s\nSurname: %s\nNick name: %s"
	  "\nProfession: %s\nPrefix: %s\nTitle: %s\nPhoto: %s"
	  "\nBirthday: Day: %s\tMonth: %s\tYear: %s",
	  first, middle, last, nick, prof, pref, 
	  title, photo, day, month, year);
  
  press_key();
  g_print("\n\nFree the memory");
  g_print("\nfree the object...");
  r_contact_free(contact); 
  g_print(" ok");
  g_print("\nfree object's copy...");
  r_contact_free(copy);
  g_print(" ok");
  
  g_print("\n\nIt works... ;-)\n\n");

  return 0;
}

==> rubrica2-2.0.8.tar.bz2: rubrica2-2.0.8/test/test_contact.c <==
#include <glib.h>
#include <glib-object.h>

#include <libral.h>

void press_key(void)
{
  gchar key;

  g_print("\npress a key");
  scanf("%c", &key);
}


int 
main(int argc, char* argv[])
{
  RContact* contact;
  RContact* copy;
  gchar *first, *middle, *last, *nick, *prof, *pref, *title, *photo;
  gchar *day, *month, *year; 
  

  g_type_init();
  r_lib_init();

  g_print("\nTesting the contact object");
  g_print("\nbuilding a new contact");
  press_key();
  
  contact = r_contact_new();

  g_print("\nFill contact with some values...");
  g_object_set(contact, 
	       "first-name", "given name", 
	       "middle-name", "middle name", 
	       "last-name", "surname", 
	       "nick-name", "TheNick", 
	       "profession", "the profession", 
	       "prefix", "the prefix", 
	       "title", "title", 
	       "photo", "/path/to/contact/photo/photo1.jpg", NULL);
  r_contact_set_birthday(contact, 1, 1, 91);

  g_print("\nCheck values");
  g_print("\nExpected values:\n\t"
	  "given name, middle name, surname, TheNick\n\t"
	  "the profession, the prefix, title\n\t"
	  "/path/to/contact/photo/photo1.jpg\n\t"
	  "1/1/91");

  g_print("\n\nGetting data...");
  g_object_get(contact, 
	       "first-name", &first, 
	       "middle-name", &middle, 
	       "last-name", &last, 
	       "nick-name", &nick,
	       "profession", &prof, 
	       "prefix", &pref,
	       "title", &title, 
	       "photo", &photo, NULL);
  day   = r_contact_get_birth_day(contact);
  month = r_contact_get_birth_month(contact);
  year  = r_contact_get_birth_year(contact);
  
  g_print("\nGiven name: %s\nMiddle name: %s\nSurname: %s\nNick name: %s"
	  "\nProfession: %s\nPrefix: %s\nTitle: %s\nPhoto: %s"
	  "\nBirthday: Day: %s\tMonth: %s\tYear: %s",
	  first, middle, last, nick, prof, pref, 
	  title, photo, day, month, year);
  g_print(" ok");


  g_print("\n\nCopying the contact...");
  copy = r_contact_copy(contact);
  g_print(" ok");

  g_print("\nGetting data from copy...");
  g_object_get(copy, 
	       "first-name", &first, 
	       "middle-name", &middle, 
	       "last-name", &last, 
	       "nick-name", &nick,
	       "profession", &prof, 
	       "prefix", &pref,
	       "title", &title, 
	       "photo", &photo, NULL);
  day   = r_contact_get_birth_day(copy);
  month = r_contact_get_birth_month(copy);
  year  = r_contact_get_birth_year(copy);
  g_print(" ok");

  g_print("\n\nWill print copy's values...");
  press_key();

  g_print("\nGiven name: %s\nMiddle name: %s\nSurname: %s\nNick name: %s"
	  "\nProfession: %s\nPrefix: %s\nTitle: %s\nPhoto: %s"
	  "\nBirthday: Day: %s\tMonth: %s\tYear: %s",
	  first, middle, last, nick, prof, pref, 
	  title, photo, day, month, year);
  
  press_key();
  g_print("\n\nFree the memory");
  g_print("\nfree the object...");
  r_contact_free(contact); 
  g_print(" ok");
  g_print("\nfree object's copy...");
  r_contact_free(copy);
  g_print(" ok");
  
  g_print("\n\nIt works... ;-)\n\n");

  return 0;
}
